@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti <https://www.jamescherti.com/contact/>
-;; Package-Version: 20260215.2013
-;; Package-Revision: 22be91a46d07
+;; Package-Version: 20260219.249
+;; Package-Revision: 21d5054bf450
 ;; URL: https://github.com/jamescherti/buffer-terminator.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "25.1"))
@@ -307,7 +307,7 @@ The messages are displayed in the *buffer-terminator* buffer."
      (buffer-terminator--insert-message "*buffer-terminator:debug*"
                                         ,(car args) ,@(cdr args))))
 
-(defun buffer-terminator--buffer-visible-p ()
+(defun buffer-terminator-buffer-visible-p ()
   "Return non-nil if the current buffer or any associated buffer is visible.
 
 This includes visibility in any window on any frame or presence in a tab-bar
@@ -368,7 +368,7 @@ base or related buffer is visible."
       t))
 
    ((eq property 'visible)
-    (when (buffer-terminator--buffer-visible-p)
+    (when (buffer-terminator-buffer-visible-p)
       t))
 
    ((eq property 'active)
